@@ -274,9 +274,19 @@ module Cinch
     # @return [void]
     # @api private
     # @since 1.0.1
-    def end_of_whois(values, not_found = false)
+    def end_of_whois(values)
       @in_whois = false
-      if not_found
+      if values.nil?
+        # for some reason, we did not receive user information. one
+        # reason is freenode throttling WHOIS
+        Thread.new do
+          sleep 2
+          refresh
+        end
+        return
+      end
+
+      if values[:unknown?]
         sync(:unknown?, true, true)
         self.online = false
         sync(:idle, 0, true)
@@ -293,16 +303,6 @@ module Cinch
         return
       end
 
-      if values.nil?
-        # for some reason, we did not receive user information. one
-        # reason is freenode throttling WHOIS
-        Thread.new do
-          sleep 2
-          refresh
-        end
-        return
-      end
-
       if values[:registered]
         values[:authname] ||= self.nick
         values.delete(:registered)
